[![Documentation Status](https://readthedocs.org/projects/ramcoh/badge/?version=latest)](https://ramcoh.readthedocs.io/en/latest/?badge=latest)
# ramCOH

Library for processing and peak fitting of Raman spectra, targeted at CO<sub>2</sub> fluids and (hydrous) silicate glasses

## Documentation
Code documentation is available at [ramcoh.readthedocs.io](https://ramcoh.readthedocs.io/en/latest)

## Installation
ramCOH can be installed with pip by running

    pip install ramCOH

in a terminal.

If you would like to install from a specific git branch or release instead run

    pip install git+https://github.com/TDGerve/ramCOH.git@tag

where *tag* should be repleaced by the release tag or branch name (e.g. *v1.0* or *development*)


